/*
 * GtkFileSelection methods tests
 * Testing GtkFileSelection methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
void  
global_activate (GtkWidget *widget, GdkEvent *event, gpointer data)
{
    if (!GTK_WIDGET_REALIZED (widget)) return;
    robot_activate (GTK_WIDGET (data));
}  

gboolean  
global_find_child_tree_view (GtkWidget *widget)
{
    GList* children = gtk_container_get_children (GTK_CONTAINER (widget));
    if (!children)
    {
        if (GTK_IS_TREE_VIEW (widget))
        {
            return TRUE;
        } else {
            return FALSE;
        }
    } else {
        GList* pchildren = g_list_first (children);
        while (pchildren)
        {
            GtkWidget* child = (GtkWidget*) pchildren->data;
            if (GTK_IS_CONTAINER (child))
            {
                gboolean found = global_find_child_tree_view (child);
                if (found == TRUE)
                {
                    return TRUE;
                }
            }
            pchildren = g_list_next (pchildren);
        }
        g_list_free (children);
    }
}

void  
global_destroy_dialog (GtkButton *button, gpointer user_data)
{
    gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (user_data)));
}  

/*
 * Name: gtk_file_selection_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Creates a new file selection dialog box.
 * Params Values: ""
 * Expected: GtkFileSelection*
 * 
 * Name: gtk_file_selection_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: By default it will contain a GtkTreeView of the application's current working directory, and a file listing.'
 * Params Values: ""
 * Expected: GtkFileSelection*  
 */
static void test_purpose_1()
{
    #define TITLE ""
    
    GtkWidget* widget;
    gboolean show_fileops;
    gboolean tree_view_found;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    tree_view_found = FALSE;
    tree_view_found = global_find_child_tree_view (widget);
    if (tree_view_found == FALSE)
    {
        TEST_FAIL ("GtkFileSelection doesn't contain a GtkTreeView", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Creates a new file selection dialog box.
 * Params Values: " "
 * Expected: GtkFileSelection*
 * 
 * Name: gtk_file_selection_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: By default it will contain a GtkTreeView of the application's current working directory, and a file listing.'
 * Params Values: " "
 * Expected: GtkFileSelection*  
 */
static void test_purpose_2()
{
    #define TITLE " "
    
    GtkWidget* widget;
    gboolean show_fileops;
    gboolean tree_view_found;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    tree_view_found = FALSE;
    tree_view_found = global_find_child_tree_view (widget);
    if (tree_view_found == FALSE)
    {
        TEST_FAIL ("GtkFileSelection doesn't contain a GtkTreeView", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Creates a new file selection dialog box.
 * Params Values: "Label"
 * Expected: GtkFileSelection*
 * 
 * Name: gtk_file_selection_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: By default it will contain a GtkTreeView of the application's current working directory, and a file listing.'
 * Params Values: "Label"
 * Expected: GtkFileSelection*  
 */
static void test_purpose_3()
{
    #define TITLE "Label"
    
    GtkWidget* widget;
    gboolean show_fileops;
    gboolean tree_view_found;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    tree_view_found = FALSE;
    tree_view_found = global_find_child_tree_view (widget);
    if (tree_view_found == FALSE)
    {
        TEST_FAIL ("GtkFileSelection doesn't contain a GtkTreeView", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Creates a new file selection dialog box.
 * Params Values: "\b\t\n"
 * Expected: GtkFileSelection*
 * 
 * Name: gtk_file_selection_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: By default it will contain a GtkTreeView of the application's current working directory, and a file listing.'
 * Params Values: "\b\t\n"
 * Expected: GtkFileSelection*  
 */
static void test_purpose_4()
{
    #define TITLE "\b\t\n"
    
    GtkWidget* widget;
    gboolean show_fileops;
    gboolean tree_view_found;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    tree_view_found = FALSE;
    tree_view_found = global_find_child_tree_view (widget);
    if (tree_view_found == FALSE)
    {
        TEST_FAIL ("GtkFileSelection doesn't contain a GtkTreeView", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Creates a new file selection dialog box.
 * Params Values: "!@#$%^&*"
 * Expected: GtkFileSelection*
 * 
 * Name: gtk_file_selection_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: By default it will contain a GtkTreeView of the application's current working directory, and a file listing.'
 * Params Values: "!@#$%^&*"
 * Expected: GtkFileSelection*  
 */
static void test_purpose_5()
{
    #define TITLE "!@#$%^&*"
    
    GtkWidget* widget;
    gboolean show_fileops;
    gboolean tree_view_found;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    tree_view_found = FALSE;
    tree_view_found = global_find_child_tree_view (widget);
    if (tree_view_found == FALSE)
    {
        TEST_FAIL ("GtkFileSelection doesn't contain a GtkTreeView", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Creates a new file selection dialog box.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
 * Expected: GtkFileSelection*
 * 
 * Name: gtk_file_selection_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: By default it will contain a GtkTreeView of the application's current working directory, and a file listing.'
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
 * Expected: GtkFileSelection*  
 */
static void test_purpose_6()
{
    #define TITLE "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    GtkWidget* widget;
    gboolean show_fileops;
    gboolean tree_view_found;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    tree_view_found = FALSE;
    tree_view_found = global_find_child_tree_view (widget);
    if (tree_view_found == FALSE)
    {
        TEST_FAIL ("GtkFileSelection doesn't contain a GtkTreeView", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_set_filename
 * Params: GtkFileSelection *filesel,const gchar *filesel
 * Returns: void
 * Assertion: Sets a default path for the file requestor.
 * Params Values: a newly created GtkFileSelection* , <%1%>
 * Expected: void  
 */
static void test_purpose_7()
{
    #define FILENAME "Text"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* filesel;
    const gchar* filename;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_file_selection_set_filename (GTK_FILE_SELECTION (widget), FILENAME);
    g_object_get(GTK_OBJECT(widget), "filename", &filename, NULL);
    if (FILENAME)
    {
        if (strcmp((char*) strstr(filename, (char*) FILENAME),  (char*) FILENAME)) 
        {
            TEST_FAIL ("filename is '%s', should be '%s'", filename, (gchar*)FILENAME);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FILENAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_set_filename
 * Params: GtkFileSelection *filesel,const gchar *filesel
 * Returns: void
 * Assertion: Sets a default path for the file requestor.
 * Params Values: a newly created GtkFileSelection* , <%1%>
 * Expected: void  
 */
static void test_purpose_8()
{
    #define FILENAME "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* filesel;
    const gchar* filename;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_file_selection_set_filename (GTK_FILE_SELECTION (widget), FILENAME);
    g_object_get(GTK_OBJECT(widget), "filename", &filename, NULL);
    if (FILENAME)
    {
        if (strcmp((char*) strstr(filename, (char*) FILENAME),  (char*) FILENAME)) 
        {
            TEST_FAIL ("filename is '%s', should be '%s'", filename, (gchar*)FILENAME);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FILENAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_set_filename
 * Params: GtkFileSelection *filesel,const gchar *filesel
 * Returns: void
 * Assertion: Sets a default path for the file requestor.
 * Params Values: a newly created GtkFileSelection* , <%1%>
 * Expected: void  
 */
static void test_purpose_9()
{
    #define FILENAME "~._"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* filesel;
    const gchar* filename;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_file_selection_set_filename (GTK_FILE_SELECTION (widget), FILENAME);
    g_object_get(GTK_OBJECT(widget), "filename", &filename, NULL);
    if (FILENAME)
    {
        if (strcmp((char*) strstr(filename, (char*) FILENAME),  (char*) FILENAME)) 
        {
            TEST_FAIL ("filename is '%s', should be '%s'", filename, (gchar*)FILENAME);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FILENAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_set_filename
 * Params: GtkFileSelection *filesel,const gchar *filesel
 * Returns: void
 * Assertion: Sets a default path for the file requestor.
 * Params Values: a newly created GtkFileSelection* , <%1%>
 * Expected: void  
 */
static void test_purpose_10()
{
    #define FILENAME "/home/abc"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* filesel;
    const gchar* filename;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_file_selection_set_filename (GTK_FILE_SELECTION (widget), FILENAME);
    g_object_get(GTK_OBJECT(widget), "filename", &filename, NULL);
    if (FILENAME)
    {
        if (strcmp((char*) strstr(filename, (char*) FILENAME),  (char*) FILENAME)) 
        {
            TEST_FAIL ("filename is '%s', should be '%s'", filename, (gchar*)FILENAME);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FILENAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_get_filename
 * Params: GtkFileSelection *filesel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: This function returns the selected filename in the on-disk encoding (see g_filename_from_utf8()), which may or may not be the same as that used by GTK+ (UTF-8).
 * Params Values: a newly created GtkFileSelection*
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_11()
{
    #define FILENAME "Text"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* filesel;
    const gchar* filename;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "filename", FILENAME, NULL);
    filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (widget));
    if (FILENAME)
    {
        if (strcmp((char*) strstr(filename, (char*) FILENAME),  (char*) FILENAME)) 
        {
            TEST_FAIL ("filename is '%s', should be '%s'", filename, (gchar*)FILENAME);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FILENAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_get_filename
 * Params: GtkFileSelection *filesel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: This function returns the selected filename in the on-disk encoding (see g_filename_from_utf8()), which may or may not be the same as that used by GTK+ (UTF-8).
 * Params Values: a newly created GtkFileSelection*
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_12()
{
    #define FILENAME "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* filesel;
    const gchar* filename;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "filename", FILENAME, NULL);
    filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (widget));
    if (FILENAME)
    {
        if (strcmp((char*) strstr(filename, (char*) FILENAME),  (char*) FILENAME)) 
        {
            TEST_FAIL ("filename is '%s', should be '%s'", filename, (gchar*)FILENAME);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FILENAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_get_filename
 * Params: GtkFileSelection *filesel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: This function returns the selected filename in the on-disk encoding (see g_filename_from_utf8()), which may or may not be the same as that used by GTK+ (UTF-8).
 * Params Values: a newly created GtkFileSelection*
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_13()
{
    #define FILENAME "~._"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* filesel;
    const gchar* filename;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "filename", FILENAME, NULL);
    filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (widget));
    if (FILENAME)
    {
        if (strcmp((char*) strstr(filename, (char*) FILENAME),  (char*) FILENAME)) 
        {
            TEST_FAIL ("filename is '%s', should be '%s'", filename, (gchar*)FILENAME);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FILENAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_get_filename
 * Params: GtkFileSelection *filesel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: This function returns the selected filename in the on-disk encoding (see g_filename_from_utf8()), which may or may not be the same as that used by GTK+ (UTF-8).
 * Params Values: a newly created GtkFileSelection*
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_14()
{
    #define FILENAME "/home/abc"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* filesel;
    const gchar* filename;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "filename", FILENAME, NULL);
    filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (widget));
    if (FILENAME)
    {
        if (strcmp((char*) strstr(filename, (char*) FILENAME),  (char*) FILENAME)) 
        {
            TEST_FAIL ("filename is '%s', should be '%s'", filename, (gchar*)FILENAME);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FILENAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_get_filename
 * Params: GtkFileSelection *filesel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: If no file is selected then the selected directory path is returned.
 * Params Values: a newly created GtkFileSelection*
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_15()
{
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* filesel;
    const gchar* filename;
    gboolean show_fileops;
    gchar* path = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_file_selection_set_filename (GTK_FILE_SELECTION (widget), "");
    
    filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (widget));
    
    path = calloc (sizeof (char),1024);
    path =(gchar*) getcwd (path,1024*sizeof(gchar));
    if (filename[strlen (filename) -1] == '/' && path[strlen (path) - 1] != '/')
        path = strcat (path,"/");
    else if (filename[strlen (filename) -1] != '/' && path[strlen (path) - 1] == '/')
        path[strlen (path) - 1] = '\0';
    
    if (strcmp((gchar*)path,(gchar*) filename)) 
    {
        TEST_FAIL ("filename is '%s', should be '%s'", filename, path);
    }
    
    
    
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: Will attempt to match pattern to a valid filenames or subdirectories in the current directory.
 * Params Values: a newly created GtkFileSelection*,"*.c"
 * Expected: void
 * 
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: If a match can be made, the matched filename will appear in the text entry field of the file selection dialog.
 * Params Values: a newly created GtkFileSelection*,"*.c"
 * Expected: void  
 */
static void test_purpose_16()
{
    #define PATTERN "*.c"
    #define CORRECT_TEXT "GtkFileSelection.c"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* text;
    gchar* work_dir;
    gchar* test_sub_dir = "/gtkvts/tests/functions/GtkFileSelection";
    int chdirres;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    work_dir = strdup (getenv ("TET_ROOT"));
    work_dir = realloc (work_dir, strlen (work_dir) + strlen (test_sub_dir) + 1);
    work_dir = strcat (work_dir, test_sub_dir);
    chdirres = chdir (work_dir);
    if (chdirres != 0)
    {
        TEST_FAIL ("can't change working directory to '%s'", work_dir);
        return;
    }
    
    widget =  gtk_file_selection_new ("FileSel");
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_file_selection_complete (GTK_FILE_SELECTION (widget), PATTERN);
    text = gtk_entry_get_text (GTK_ENTRY ((GTK_FILE_SELECTION (widget))->selection_entry));
    
    if (CORRECT_TEXT == NULL)
    {
        if (text != NULL)
        {
            TEST_FAIL ("text = '%s', should be NULL", text);
        }
    } else {
        if (text == NULL)
        {
            TEST_FAIL ("text = NULL, should be '%s'", CORRECT_TEXT);
        } else if (strcmp (text, CORRECT_TEXT)) {
            TEST_FAIL ("text = '%s', should be '%s'", text, CORRECT_TEXT);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PATTERN
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: Will attempt to match pattern to a valid filenames or subdirectories in the current directory.
 * Params Values: a newly created GtkFileSelection*,"Gtk"
 * Expected: void
 * 
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: If a match can be made, the matched filename will appear in the text entry field of the file selection dialog.
 * Params Values: a newly created GtkFileSelection*,"Gtk"
 * Expected: void  
 */
static void test_purpose_17()
{
    #define PATTERN "Gtk"
    #define CORRECT_TEXT "GtkFileSelection"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* text;
    gchar* work_dir;
    gchar* test_sub_dir = "/gtkvts/tests/functions/GtkFileSelection";
    int chdirres;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    work_dir = strdup (getenv ("TET_ROOT"));
    work_dir = realloc (work_dir, strlen (work_dir) + strlen (test_sub_dir) + 1);
    work_dir = strcat (work_dir, test_sub_dir);
    chdirres = chdir (work_dir);
    if (chdirres != 0)
    {
        TEST_FAIL ("can't change working directory to '%s'", work_dir);
        return;
    }
    
    widget =  gtk_file_selection_new ("FileSel");
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_file_selection_complete (GTK_FILE_SELECTION (widget), PATTERN);
    text = gtk_entry_get_text (GTK_ENTRY ((GTK_FILE_SELECTION (widget))->selection_entry));
    
    if (CORRECT_TEXT == NULL)
    {
        if (text != NULL)
        {
            TEST_FAIL ("text = '%s', should be NULL", text);
        }
    } else {
        if (text == NULL)
        {
            TEST_FAIL ("text = NULL, should be '%s'", CORRECT_TEXT);
        } else if (strcmp (text, CORRECT_TEXT)) {
            TEST_FAIL ("text = '%s', should be '%s'", text, CORRECT_TEXT);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PATTERN
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: Will attempt to match pattern to a valid filenames or subdirectories in the current directory.
 * Params Values: a newly created GtkFileSelection*,"G*"
 * Expected: void
 * 
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: If a match can be made, the matched filename will appear in the text entry field of the file selection dialog.
 * Params Values: a newly created GtkFileSelection*,"G*"
 * Expected: void  
 */
static void test_purpose_18()
{
    #define PATTERN "G*"
    #define CORRECT_TEXT "GtkFileSelection"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* text;
    gchar* work_dir;
    gchar* test_sub_dir = "/gtkvts/tests/functions/GtkFileSelection";
    int chdirres;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    work_dir = strdup (getenv ("TET_ROOT"));
    work_dir = realloc (work_dir, strlen (work_dir) + strlen (test_sub_dir) + 1);
    work_dir = strcat (work_dir, test_sub_dir);
    chdirres = chdir (work_dir);
    if (chdirres != 0)
    {
        TEST_FAIL ("can't change working directory to '%s'", work_dir);
        return;
    }
    
    widget =  gtk_file_selection_new ("FileSel");
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_file_selection_complete (GTK_FILE_SELECTION (widget), PATTERN);
    text = gtk_entry_get_text (GTK_ENTRY ((GTK_FILE_SELECTION (widget))->selection_entry));
    
    if (CORRECT_TEXT == NULL)
    {
        if (text != NULL)
        {
            TEST_FAIL ("text = '%s', should be NULL", text);
        }
    } else {
        if (text == NULL)
        {
            TEST_FAIL ("text = NULL, should be '%s'", CORRECT_TEXT);
        } else if (strcmp (text, CORRECT_TEXT)) {
            TEST_FAIL ("text = '%s', should be '%s'", text, CORRECT_TEXT);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PATTERN
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: Will attempt to match pattern to a valid filenames or subdirectories in the current directory.
 * Params Values: a newly created GtkFileSelection*,"GtkFileSelection"
 * Expected: void
 * 
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: If a match can be made, the matched filename will appear in the text entry field of the file selection dialog.
 * Params Values: a newly created GtkFileSelection*,"GtkFileSelection"
 * Expected: void  
 */
static void test_purpose_19()
{
    #define PATTERN "GtkFileSelection"
    #define CORRECT_TEXT "GtkFileSelection"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* text;
    gchar* work_dir;
    gchar* test_sub_dir = "/gtkvts/tests/functions/GtkFileSelection";
    int chdirres;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    work_dir = strdup (getenv ("TET_ROOT"));
    work_dir = realloc (work_dir, strlen (work_dir) + strlen (test_sub_dir) + 1);
    work_dir = strcat (work_dir, test_sub_dir);
    chdirres = chdir (work_dir);
    if (chdirres != 0)
    {
        TEST_FAIL ("can't change working directory to '%s'", work_dir);
        return;
    }
    
    widget =  gtk_file_selection_new ("FileSel");
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_file_selection_complete (GTK_FILE_SELECTION (widget), PATTERN);
    text = gtk_entry_get_text (GTK_ENTRY ((GTK_FILE_SELECTION (widget))->selection_entry));
    
    if (CORRECT_TEXT == NULL)
    {
        if (text != NULL)
        {
            TEST_FAIL ("text = '%s', should be NULL", text);
        }
    } else {
        if (text == NULL)
        {
            TEST_FAIL ("text = NULL, should be '%s'", CORRECT_TEXT);
        } else if (strcmp (text, CORRECT_TEXT)) {
            TEST_FAIL ("text = '%s', should be '%s'", text, CORRECT_TEXT);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PATTERN
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: Will attempt to match pattern to a valid filenames or subdirectories in the current directory.
 * Params Values: a newly created GtkFileSelection*,"*.*"
 * Expected: void
 * 
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: If a match can be made, the matched filename will appear in the text entry field of the file selection dialog.
 * Params Values: a newly created GtkFileSelection*,"*.*"
 * Expected: void  
 */
static void test_purpose_20()
{
    #define PATTERN "*.*"
    #define CORRECT_TEXT "GtkFileSelection.c"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* text;
    gchar* work_dir;
    gchar* test_sub_dir = "/gtkvts/tests/functions/GtkFileSelection";
    int chdirres;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    work_dir = strdup (getenv ("TET_ROOT"));
    work_dir = realloc (work_dir, strlen (work_dir) + strlen (test_sub_dir) + 1);
    work_dir = strcat (work_dir, test_sub_dir);
    chdirres = chdir (work_dir);
    if (chdirres != 0)
    {
        TEST_FAIL ("can't change working directory to '%s'", work_dir);
        return;
    }
    
    widget =  gtk_file_selection_new ("FileSel");
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_file_selection_complete (GTK_FILE_SELECTION (widget), PATTERN);
    text = gtk_entry_get_text (GTK_ENTRY ((GTK_FILE_SELECTION (widget))->selection_entry));
    
    if (CORRECT_TEXT == NULL)
    {
        if (text != NULL)
        {
            TEST_FAIL ("text = '%s', should be NULL", text);
        }
    } else {
        if (text == NULL)
        {
            TEST_FAIL ("text = NULL, should be '%s'", CORRECT_TEXT);
        } else if (strcmp (text, CORRECT_TEXT)) {
            TEST_FAIL ("text = '%s', should be '%s'", text, CORRECT_TEXT);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PATTERN
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: Will attempt to match pattern to a valid filenames or subdirectories in the current directory.
 * Params Values: a newly created GtkFileSelection*,""
 * Expected: void
 * 
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: If a match can be made, the matched filename will appear in the text entry field of the file selection dialog.
 * Params Values: a newly created GtkFileSelection*,""
 * Expected: void  
 */
static void test_purpose_21()
{
    #define PATTERN ""
    #define CORRECT_TEXT "GtkFileSelection"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* text;
    gchar* work_dir;
    gchar* test_sub_dir = "/gtkvts/tests/functions/GtkFileSelection";
    int chdirres;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    work_dir = strdup (getenv ("TET_ROOT"));
    work_dir = realloc (work_dir, strlen (work_dir) + strlen (test_sub_dir) + 1);
    work_dir = strcat (work_dir, test_sub_dir);
    chdirres = chdir (work_dir);
    if (chdirres != 0)
    {
        TEST_FAIL ("can't change working directory to '%s'", work_dir);
        return;
    }
    
    widget =  gtk_file_selection_new ("FileSel");
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_file_selection_complete (GTK_FILE_SELECTION (widget), PATTERN);
    text = gtk_entry_get_text (GTK_ENTRY ((GTK_FILE_SELECTION (widget))->selection_entry));
    
    if (CORRECT_TEXT == NULL)
    {
        if (text != NULL)
        {
            TEST_FAIL ("text = '%s', should be NULL", text);
        }
    } else {
        if (text == NULL)
        {
            TEST_FAIL ("text = NULL, should be '%s'", CORRECT_TEXT);
        } else if (strcmp (text, CORRECT_TEXT)) {
            TEST_FAIL ("text = '%s', should be '%s'", text, CORRECT_TEXT);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PATTERN
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: Will attempt to match pattern to a valid filenames or subdirectories in the current directory.
 * Params Values: a newly created GtkFileSelection*,NULL
 * Expected: void
 * 
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: If a match can be made, the matched filename will appear in the text entry field of the file selection dialog.
 * Params Values: a newly created GtkFileSelection*,NULL
 * Expected: void  
 */
static void test_purpose_22()
{
    #define PATTERN NULL
    #define CORRECT_TEXT ""
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* text;
    gchar* work_dir;
    gchar* test_sub_dir = "/gtkvts/tests/functions/GtkFileSelection";
    int chdirres;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    work_dir = strdup (getenv ("TET_ROOT"));
    work_dir = realloc (work_dir, strlen (work_dir) + strlen (test_sub_dir) + 1);
    work_dir = strcat (work_dir, test_sub_dir);
    chdirres = chdir (work_dir);
    if (chdirres != 0)
    {
        TEST_FAIL ("can't change working directory to '%s'", work_dir);
        return;
    }
    
    widget =  gtk_file_selection_new ("FileSel");
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_file_selection_complete (GTK_FILE_SELECTION (widget), PATTERN);
    text = gtk_entry_get_text (GTK_ENTRY ((GTK_FILE_SELECTION (widget))->selection_entry));
    
    if (CORRECT_TEXT == NULL)
    {
        if (text != NULL)
        {
            TEST_FAIL ("text = '%s', should be NULL", text);
        }
    } else {
        if (text == NULL)
        {
            TEST_FAIL ("text = NULL, should be '%s'", CORRECT_TEXT);
        } else if (strcmp (text, CORRECT_TEXT)) {
            TEST_FAIL ("text = '%s', should be '%s'", text, CORRECT_TEXT);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PATTERN
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: If a partial match can be made, the "Files" list will contain those file names which have been partially matched, and the "Folders" list those directories which have been partially matched. 
 * Params Values: a newly created GtkFileSelection*, "GtkFile"
 * Expected: void  
 */
static void test_purpose_23()
{
    #define TEST_SUBDIR "/gtkvts/tests/functions/GtkFileSelection"
    #define PATTERN "GtkFile"
    #define CORRECT_FOLDERS_ITEMS {"./", "../"}
    #define CORRECT_FILES_ITEMS {"GtkFileSelection", "GtkFileSelection.c"}
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* text;
    gchar* work_dir;
    gchar* correct_folders_items[] = CORRECT_FOLDERS_ITEMS;
    gchar* correct_files_items[] = CORRECT_FILES_ITEMS;
    int chdirres;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    work_dir = strdup (getenv ("TET_ROOT"));
    work_dir = realloc (work_dir, strlen (work_dir) + strlen (TEST_SUBDIR) + 1);
    work_dir = strcat (work_dir, TEST_SUBDIR);
    chdirres = chdir (work_dir);
    if (chdirres != 0)
    {
        TEST_FAIL ("can't change working directory to '%s'", work_dir);
        return;
    }
    
    widget =  gtk_file_selection_new ("FileSel");
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_file_selection_complete (GTK_FILE_SELECTION (widget), PATTERN);
    
    if (strcmp (correct_folders_items[0], "<nothing>"))
    {
        int i;
        for (i = 0; 
             i < sizeof (correct_folders_items)/sizeof (correct_folders_items[0]);
             i++)
        {
            GtkTreeIter iter;
            G_CONST_RETURN gchar* str_value;
            GValue val = {0,};
            char *path_str = calloc (sizeof (char), 8);
            
            sprintf (path_str, "%d", i);
            gtk_tree_model_get_iter  
                (gtk_tree_view_get_model((GtkTreeView*)(GTK_FILE_SELECTION (widget))->dir_list), 
                 &iter, 
                 gtk_tree_path_new_from_string ((const gchar*) path_str));
            gtk_tree_model_get_value 
                (gtk_tree_view_get_model((GtkTreeView*)(GTK_FILE_SELECTION (widget))->dir_list), 
                 &iter, 
                 0, 
                 &val);
            str_value = g_value_get_string (&val);
            
            if (!str_value)
            {
                TEST_FAIL ("str_value = NULL, i = %d", i);
            } else if (strcmp (str_value, correct_folders_items[i])) {
                TEST_FAIL ("str_value = '%s', should be '%s', i = %d", 
                           str_value, correct_folders_items[i], i);
            }
        }
    }
    
    if (strcmp (correct_files_items[0], "<nothing>"))
    {
        int i;
        for (i = 0; 
             i < sizeof (correct_files_items)/sizeof (correct_files_items[0]);
             i++)
        {
            GtkTreeIter iter;
            G_CONST_RETURN gchar* str_value;
            GValue val = {0,};
            char *path_str = calloc (sizeof (char), 8);
            
            sprintf (path_str, "%d", i);
            gtk_tree_model_get_iter  
                (gtk_tree_view_get_model((GtkTreeView*)(GTK_FILE_SELECTION (widget))->file_list), 
                 &iter, 
                 gtk_tree_path_new_from_string ((const gchar*) path_str));
            gtk_tree_model_get_value 
                (gtk_tree_view_get_model((GtkTreeView*)(GTK_FILE_SELECTION (widget))->file_list), 
                 &iter, 
                 0, 
                 &val);
            str_value = g_value_get_string (&val);
            
            if (!str_value)
            {
                TEST_FAIL ("str_value = NULL, i = %d", i);
            } else if (strcmp (str_value, correct_files_items[i])) {
                TEST_FAIL ("str_value = '%s', should be '%s', i = %d", 
                           str_value, correct_files_items[i], i);
            }
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_SUBDIR
    #undef PATTERN
    #undef CORRECT_FOLDERS_ITEMS
    #undef CORRECT_FILES_ITEMS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_complete
 * Params: GtkFileSelection *filesel, const gchar *pattern
 * Returns: void
 * Assertion: If a partial match can be made, the "Files" list will contain those file names which have been partially matched, and the "Folders" list those directories which have been partially matched. 
 * Params Values: a newly created GtkFileSelection*, "GtkBu"
 * Expected: void  
 */
static void test_purpose_24()
{
    #define TEST_SUBDIR "/gtkvts/tests/functions/"
    #define PATTERN "GtkBu"
    #define CORRECT_FOLDERS_ITEMS {"./", "../", "GtkButton/", "GtkButtonBox/"}
    #define CORRECT_FILES_ITEMS {"<nothing>"}
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* text;
    gchar* work_dir;
    gchar* correct_folders_items[] = CORRECT_FOLDERS_ITEMS;
    gchar* correct_files_items[] = CORRECT_FILES_ITEMS;
    int chdirres;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    work_dir = strdup (getenv ("TET_ROOT"));
    work_dir = realloc (work_dir, strlen (work_dir) + strlen (TEST_SUBDIR) + 1);
    work_dir = strcat (work_dir, TEST_SUBDIR);
    chdirres = chdir (work_dir);
    if (chdirres != 0)
    {
        TEST_FAIL ("can't change working directory to '%s'", work_dir);
        return;
    }
    
    widget =  gtk_file_selection_new ("FileSel");
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_file_selection_complete (GTK_FILE_SELECTION (widget), PATTERN);
    
    if (strcmp (correct_folders_items[0], "<nothing>"))
    {
        int i;
        for (i = 0; 
             i < sizeof (correct_folders_items)/sizeof (correct_folders_items[0]);
             i++)
        {
            GtkTreeIter iter;
            G_CONST_RETURN gchar* str_value;
            GValue val = {0,};
            char *path_str = calloc (sizeof (char), 8);
            
            sprintf (path_str, "%d", i);
            gtk_tree_model_get_iter  
                (gtk_tree_view_get_model((GtkTreeView*)(GTK_FILE_SELECTION (widget))->dir_list), 
                 &iter, 
                 gtk_tree_path_new_from_string ((const gchar*) path_str));
            gtk_tree_model_get_value 
                (gtk_tree_view_get_model((GtkTreeView*)(GTK_FILE_SELECTION (widget))->dir_list), 
                 &iter, 
                 0, 
                 &val);
            str_value = g_value_get_string (&val);
            
            if (!str_value)
            {
                TEST_FAIL ("str_value = NULL, i = %d", i);
            } else if (strcmp (str_value, correct_folders_items[i])) {
                TEST_FAIL ("str_value = '%s', should be '%s', i = %d", 
                           str_value, correct_folders_items[i], i);
            }
        }
    }
    
    if (strcmp (correct_files_items[0], "<nothing>"))
    {
        int i;
        for (i = 0; 
             i < sizeof (correct_files_items)/sizeof (correct_files_items[0]);
             i++)
        {
            GtkTreeIter iter;
            G_CONST_RETURN gchar* str_value;
            GValue val = {0,};
            char *path_str = calloc (sizeof (char), 8);
            
            sprintf (path_str, "%d", i);
            gtk_tree_model_get_iter  
                (gtk_tree_view_get_model((GtkTreeView*)(GTK_FILE_SELECTION (widget))->file_list), 
                 &iter, 
                 gtk_tree_path_new_from_string ((const gchar*) path_str));
            gtk_tree_model_get_value 
                (gtk_tree_view_get_model((GtkTreeView*)(GTK_FILE_SELECTION (widget))->file_list), 
                 &iter, 
                 0, 
                 &val);
            str_value = g_value_get_string (&val);
            
            if (!str_value)
            {
                TEST_FAIL ("str_value = NULL, i = %d", i);
            } else if (strcmp (str_value, correct_files_items[i])) {
                TEST_FAIL ("str_value = '%s', should be '%s', i = %d", 
                           str_value, correct_files_items[i], i);
            }
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_SUBDIR
    #undef PATTERN
    #undef CORRECT_FOLDERS_ITEMS
    #undef CORRECT_FILES_ITEMS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_show_fileop_buttons
 * Params: GtkFileSelection *filesel
 * Returns: void
 * Assertion: Shows the file operation buttons, if they have previously been hidden.
 * Params Values: a newly created GtkFileSelection*
 * Expected: void  
 */
static void test_purpose_25()
{
    #define TITLE NULL
    GtkWidget* widget;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    
    g_object_set(GTK_OBJECT(widget), "show-fileops", FALSE, NULL);
    
    gtk_file_selection_show_fileop_buttons (GTK_FILE_SELECTION (widget));
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_show_fileop_buttons
 * Params: GtkFileSelection *filesel
 * Returns: void
 * Assertion: Shows the file operation buttons, if they have previously been hidden.
 * Params Values: a newly created GtkFileSelection*
 * Expected: void  
 */
static void test_purpose_26()
{
    #define TITLE ""
    GtkWidget* widget;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    
    g_object_set(GTK_OBJECT(widget), "show-fileops", FALSE, NULL);
    
    gtk_file_selection_show_fileop_buttons (GTK_FILE_SELECTION (widget));
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_show_fileop_buttons
 * Params: GtkFileSelection *filesel
 * Returns: void
 * Assertion: Shows the file operation buttons, if they have previously been hidden.
 * Params Values: a newly created GtkFileSelection*
 * Expected: void  
 */
static void test_purpose_27()
{
    #define TITLE " "
    GtkWidget* widget;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    
    g_object_set(GTK_OBJECT(widget), "show-fileops", FALSE, NULL);
    
    gtk_file_selection_show_fileop_buttons (GTK_FILE_SELECTION (widget));
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_show_fileop_buttons
 * Params: GtkFileSelection *filesel
 * Returns: void
 * Assertion: Shows the file operation buttons, if they have previously been hidden.
 * Params Values: a newly created GtkFileSelection*
 * Expected: void  
 */
static void test_purpose_28()
{
    #define TITLE "Label"
    GtkWidget* widget;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    
    g_object_set(GTK_OBJECT(widget), "show-fileops", FALSE, NULL);
    
    gtk_file_selection_show_fileop_buttons (GTK_FILE_SELECTION (widget));
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_show_fileop_buttons
 * Params: GtkFileSelection *filesel
 * Returns: void
 * Assertion: Shows the file operation buttons, if they have previously been hidden.
 * Params Values: a newly created GtkFileSelection*
 * Expected: void  
 */
static void test_purpose_29()
{
    #define TITLE "\b\t\n"
    GtkWidget* widget;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    
    g_object_set(GTK_OBJECT(widget), "show-fileops", FALSE, NULL);
    
    gtk_file_selection_show_fileop_buttons (GTK_FILE_SELECTION (widget));
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_show_fileop_buttons
 * Params: GtkFileSelection *filesel
 * Returns: void
 * Assertion: Shows the file operation buttons, if they have previously been hidden.
 * Params Values: a newly created GtkFileSelection*
 * Expected: void  
 */
static void test_purpose_30()
{
    #define TITLE "!@#$%^&*"
    GtkWidget* widget;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    
    g_object_set(GTK_OBJECT(widget), "show-fileops", FALSE, NULL);
    
    gtk_file_selection_show_fileop_buttons (GTK_FILE_SELECTION (widget));
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_show_fileop_buttons
 * Params: GtkFileSelection *filesel
 * Returns: void
 * Assertion: Shows the file operation buttons, if they have previously been hidden.
 * Params Values: a newly created GtkFileSelection*
 * Expected: void  
 */
static void test_purpose_31()
{
    #define TITLE "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    GtkWidget* widget;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    
    g_object_set(GTK_OBJECT(widget), "show-fileops", FALSE, NULL);
    
    gtk_file_selection_show_fileop_buttons (GTK_FILE_SELECTION (widget));
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (!show_fileops) 
    {
        TEST_FAIL ("show_fileops is FALSE, should be TRUE",NULL);
    }
    
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_hide_fileop_buttons 
 * Params: GtkFileSelection *filesel
 * Returns: void
 * Assertion: Hides the file operation buttons that normally appear at the top of the dialog.
 * Params Values: a newly created GtkFileSelection*
 * Expected: void  
 */
static void test_purpose_32()
{
    #define TITLE NULL
    GtkWidget* widget;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    g_object_set(GTK_OBJECT(widget), "show-fileops", TRUE, NULL);
    
    gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (widget));
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (show_fileops) 
    {
        TEST_FAIL ("show_fileops is TRUE, should be FALSE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_hide_fileop_buttons 
 * Params: GtkFileSelection *filesel
 * Returns: void
 * Assertion: Hides the file operation buttons that normally appear at the top of the dialog.
 * Params Values: a newly created GtkFileSelection*
 * Expected: void  
 */
static void test_purpose_33()
{
    #define TITLE ""
    GtkWidget* widget;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    g_object_set(GTK_OBJECT(widget), "show-fileops", TRUE, NULL);
    
    gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (widget));
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (show_fileops) 
    {
        TEST_FAIL ("show_fileops is TRUE, should be FALSE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_hide_fileop_buttons 
 * Params: GtkFileSelection *filesel
 * Returns: void
 * Assertion: Hides the file operation buttons that normally appear at the top of the dialog.
 * Params Values: a newly created GtkFileSelection*
 * Expected: void  
 */
static void test_purpose_34()
{
    #define TITLE " "
    GtkWidget* widget;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    g_object_set(GTK_OBJECT(widget), "show-fileops", TRUE, NULL);
    
    gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (widget));
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (show_fileops) 
    {
        TEST_FAIL ("show_fileops is TRUE, should be FALSE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_hide_fileop_buttons 
 * Params: GtkFileSelection *filesel
 * Returns: void
 * Assertion: Hides the file operation buttons that normally appear at the top of the dialog.
 * Params Values: a newly created GtkFileSelection*
 * Expected: void  
 */
static void test_purpose_35()
{
    #define TITLE "Label"
    GtkWidget* widget;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    g_object_set(GTK_OBJECT(widget), "show-fileops", TRUE, NULL);
    
    gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (widget));
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (show_fileops) 
    {
        TEST_FAIL ("show_fileops is TRUE, should be FALSE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_hide_fileop_buttons 
 * Params: GtkFileSelection *filesel
 * Returns: void
 * Assertion: Hides the file operation buttons that normally appear at the top of the dialog.
 * Params Values: a newly created GtkFileSelection*
 * Expected: void  
 */
static void test_purpose_36()
{
    #define TITLE "\b\t\n"
    GtkWidget* widget;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    g_object_set(GTK_OBJECT(widget), "show-fileops", TRUE, NULL);
    
    gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (widget));
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (show_fileops) 
    {
        TEST_FAIL ("show_fileops is TRUE, should be FALSE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_hide_fileop_buttons 
 * Params: GtkFileSelection *filesel
 * Returns: void
 * Assertion: Hides the file operation buttons that normally appear at the top of the dialog.
 * Params Values: a newly created GtkFileSelection*
 * Expected: void  
 */
static void test_purpose_37()
{
    #define TITLE "!@#$%^&*"
    GtkWidget* widget;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    g_object_set(GTK_OBJECT(widget), "show-fileops", TRUE, NULL);
    
    gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (widget));
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (show_fileops) 
    {
        TEST_FAIL ("show_fileops is TRUE, should be FALSE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_hide_fileop_buttons 
 * Params: GtkFileSelection *filesel
 * Returns: void
 * Assertion: Hides the file operation buttons that normally appear at the top of the dialog.
 * Params Values: a newly created GtkFileSelection*
 * Expected: void  
 */
static void test_purpose_38()
{
    #define TITLE "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    GtkWidget* widget;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new (TITLE);
    
    g_object_set(GTK_OBJECT(widget), "show-fileops", TRUE, NULL);
    
    gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (widget));
    g_object_get(GTK_OBJECT(widget), "show-fileops", &show_fileops, NULL);
    if (show_fileops) 
    {
        TEST_FAIL ("show_fileops is TRUE, should be FALSE",NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_set_select_multiple
 * Params: GtkFileSelection *filesel,gboolean select_multiple
 * Returns: void
 * Assertion: Sets whether the user is allowed to select multiple files in the file list.
 * Params Values: a newly created GtkFileSelection* , <%1%>
 * Expected: void
 * 
 * Name: gtk_file_selection_get_select_multiple
 * Params: GtkFileSelection *filesel,gboolean select_multiple
 * Returns: void
 * Assertion: Determines whether or not the user is allowed to select multiple files in the file list.
 * Params Values: a newly created GtkFileSelection* , <%1%>
 * Expected: void  
 */
static void test_purpose_39()
{
    #define MULTIPLE TRUE
    
    GtkWidget* widget;
    gboolean multiple;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_file_selection_set_select_multiple  (GTK_FILE_SELECTION (widget), MULTIPLE);
    
    multiple = gtk_file_selection_get_select_multiple (GTK_FILE_SELECTION (widget));
    if (multiple != MULTIPLE)
    {
        TEST_FAIL ("select_multiple is '%d',should be '%d'",multiple,MULTIPLE);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MULTIPLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_set_select_multiple
 * Params: GtkFileSelection *filesel,gboolean select_multiple
 * Returns: void
 * Assertion: Sets whether the user is allowed to select multiple files in the file list.
 * Params Values: a newly created GtkFileSelection* , <%1%>
 * Expected: void
 * 
 * Name: gtk_file_selection_get_select_multiple
 * Params: GtkFileSelection *filesel,gboolean select_multiple
 * Returns: void
 * Assertion: Determines whether or not the user is allowed to select multiple files in the file list.
 * Params Values: a newly created GtkFileSelection* , <%1%>
 * Expected: void  
 */
static void test_purpose_40()
{
    #define MULTIPLE FALSE
    
    GtkWidget* widget;
    gboolean multiple;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_file_selection_set_select_multiple  (GTK_FILE_SELECTION (widget), MULTIPLE);
    
    multiple = gtk_file_selection_get_select_multiple (GTK_FILE_SELECTION (widget));
    if (multiple != MULTIPLE)
    {
        TEST_FAIL ("select_multiple is '%d',should be '%d'",multiple,MULTIPLE);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MULTIPLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_get_selections
 * Params: GtkFileSelection *filesel
 * Returns: gchar**
 * Assertion: The first file in the list is equivalent to what gtk_file_selection_get_filename() would return.
 * Params Values: a newly created GtkFileSelection*
 * Expected: gchar**  
 */
static void test_purpose_41()
{
    #define FILENAME "Text"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* filesel;
    const gchar* filename;
    gchar** file;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "filename", FILENAME, NULL);
    filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (widget));
    
    file = gtk_file_selection_get_selections (GTK_FILE_SELECTION (widget));
    
    if (strcmp (filename,*file))
    {
        TEST_FAIL ("The first file in the list is not equivalent to what gtk_file_selection_get_filename() would return.",NULL)
    }
    
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FILENAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_get_selections
 * Params: GtkFileSelection *filesel
 * Returns: gchar**
 * Assertion: The first file in the list is equivalent to what gtk_file_selection_get_filename() would return.
 * Params Values: a newly created GtkFileSelection*
 * Expected: gchar**  
 */
static void test_purpose_42()
{
    #define FILENAME "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* filesel;
    const gchar* filename;
    gchar** file;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "filename", FILENAME, NULL);
    filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (widget));
    
    file = gtk_file_selection_get_selections (GTK_FILE_SELECTION (widget));
    
    if (strcmp (filename,*file))
    {
        TEST_FAIL ("The first file in the list is not equivalent to what gtk_file_selection_get_filename() would return.",NULL)
    }
    
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FILENAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_get_selections
 * Params: GtkFileSelection *filesel
 * Returns: gchar**
 * Assertion: The first file in the list is equivalent to what gtk_file_selection_get_filename() would return.
 * Params Values: a newly created GtkFileSelection*
 * Expected: gchar**  
 */
static void test_purpose_43()
{
    #define FILENAME "~._"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* filesel;
    const gchar* filename;
    gchar** file;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "filename", FILENAME, NULL);
    filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (widget));
    
    file = gtk_file_selection_get_selections (GTK_FILE_SELECTION (widget));
    
    if (strcmp (filename,*file))
    {
        TEST_FAIL ("The first file in the list is not equivalent to what gtk_file_selection_get_filename() would return.",NULL)
    }
    
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FILENAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_get_selections
 * Params: GtkFileSelection *filesel
 * Returns: gchar**
 * Assertion: The first file in the list is equivalent to what gtk_file_selection_get_filename() would return.
 * Params Values: a newly created GtkFileSelection*
 * Expected: gchar**  
 */
static void test_purpose_44()
{
    #define FILENAME "/home/abc"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* filesel;
    const gchar* filename;
    gchar** file;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "filename", FILENAME, NULL);
    filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (widget));
    
    file = gtk_file_selection_get_selections (GTK_FILE_SELECTION (widget));
    
    if (strcmp (filename,*file))
    {
        TEST_FAIL ("The first file in the list is not equivalent to what gtk_file_selection_get_filename() would return.",NULL)
    }
    
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FILENAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_file_selection_get_selections
 * Params: GtkFileSelection *filesel
 * Returns: gchar**
 * Assertion: The first file in the list is equivalent to what gtk_file_selection_get_filename() would return.
 * Params Values: a newly created GtkFileSelection*
 * Expected: gchar**  
 */
static void test_purpose_45()
{
    #define FILENAME "/"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* filesel;
    const gchar* filename;
    gchar** file;
    gboolean show_fileops;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_file_selection_new ("title");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FILE_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "filename", FILENAME, NULL);
    filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (widget));
    
    file = gtk_file_selection_get_selections (GTK_FILE_SELECTION (widget));
    
    if (strcmp (filename,*file))
    {
        TEST_FAIL ("The first file in the list is not equivalent to what gtk_file_selection_get_filename() would return.",NULL)
    }
    
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FILE_SELECTION (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_dialog_run (GTK_DIALOG (widget));
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FILENAME
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkFileSelection ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {NULL,0}
};
